@@ -130,6 +130,8 @@ class Base(object):
             conditions = []
         if or_cond is None:
             or_cond = []
+        if len(or_cond) + len(conditions) == 0:
+            return sql[:-7]
 
         if len(conditions) > 0:
             for unit in conditions:
